package com.blamejared.compat.botania.lexicon.pages;

import vazkii.botania.api.lexicon.LexiconPage;
import vazkii.botania.api.lexicon.LexiconEntry;
import java.util.List;
import vazkii.botania.common.lexicon.page.PageManaInfusionRecipe;
import com.blamejared.mtlib.helpers.InputHelper;
import vazkii.botania.api.recipe.RecipeManaInfusion;
import java.util.ArrayList;
import crafttweaker.CraftTweakerAPI;
import com.blamejared.compat.botania.BotaniaHelper;
import crafttweaker.api.item.IIngredient;
import crafttweaker.api.item.IItemStack;
import crafttweaker.IAction;

public class AddPageAlchemy implements IAction
{
    private String name;
    private String entry;
    private int page_number;
    private IItemStack[] outputs;
    private IIngredient[] inputs;
    private int[] mana;
    
    public AddPageAlchemy(final String name, final String entry, final int page_number, final IItemStack[] outputs, final IIngredient[] inputs, final int[] mana) {
        this.name = name;
        this.entry = entry;
        this.page_number = page_number;
        this.outputs = outputs;
        this.inputs = inputs;
        this.mana = mana;
    }
    
    public void apply() {
        final LexiconEntry lexiconEntry = BotaniaHelper.findEntry(this.entry);
        if (lexiconEntry == null) {
            CraftTweakerAPI.getLogger().logError("Cannot find lexicon entry " + this.entry);
            return;
        }
        if (this.page_number > lexiconEntry.pages.size()) {
            CraftTweakerAPI.getLogger().logError("Page Number " + this.page_number + " out of bounds for " + this.entry);
            return;
        }
        if (this.outputs.length != this.inputs.length || this.outputs.length != this.mana.length) {
            CraftTweakerAPI.getLogger().logError("Length of input and output must match");
            return;
        }
        final List<RecipeManaInfusion> recipes = new ArrayList<RecipeManaInfusion>();
        for (int i = 0; i < this.outputs.length; ++i) {
            final RecipeManaInfusion current_recipe = new RecipeManaInfusion(InputHelper.toStack(this.outputs[i]), InputHelper.toObject(this.inputs[i]), this.mana[i]);
            current_recipe.setCatalyst(RecipeManaInfusion.alchemyState);
            recipes.add(current_recipe);
        }
        final LexiconPage page = (LexiconPage)new PageManaInfusionRecipe(this.name, (List)recipes);
        lexiconEntry.pages.add(this.page_number, page);
    }
    
    public String describe() {
        return "Adding Lexicon Page: " + this.name;
    }
}
